/**
 * Earth's hemispheres.
 */
export declare enum Hemisphere {
    NORTHERN = "Northern",
    SOUTHERN = "Southern"
}

/**
 * Julian calendar, chronological days since noon Universal Time on January 1, 4713 BC
 */
export declare class Julian {
    /**
     * Julian day from Gregorian date.
     */
    static fromDate(date?: Date): number;
    /**
     * Gregorian date from Julian day
     */
    static toDate(julian: number): Date;
}

/**
 * Lunar month, time between two successive syzygies of the
 * same type: new moons or full moons
 */
export declare enum LunarMonth {
    ANOMALISTIC = "Anomalistic",
    DRACONIC = "Draconic",
    SIDEREAL = "Sidereal",
    SYNODIC = "Synodic",
    TROPICAL = "Tropical"
}

/**
 * Enumeration of lunar phases
 */
export declare enum LunarPhase {
    NEW = "New",
    WAXING_CRESCENT = "Waxing Crescent",
    FIRST_QUARTER = "First Quarter",
    WAXING_GIBBOUS = "Waxing Gibbous",
    FULL = "Full",
    WANING_GIBBOUS = "Waning Gibbous",
    LAST_QUARTER = "Last Quarter",
    WANING_CRESCENT = "Waning Crescent"
}

/**
 * Calculations relating to Earth's moon.
 */
export declare class Moon {
    /**
     * Moon's age, or Earth days since the last new moon,
     * normalized within a 29.53059 Earth days calendar.
     */
    static lunarAge(date?: Date): number;
    /**
     * Percentage through the lunar synodic month.
     */
    static lunarAgePercent(date?: Date): number;
    /**
     * Brown Lunation Number (BLN), per Ernest William Brown's lunar theory,
     * defining Lunation 1 as the first new moon of 1923 at
     * approximately 02:41 UTC, January 17, 1923.
     */
    static lunationNumber(date?: Date): number;
    /**
     * Distance to the moon measured in units of Earth radii, with
     * perigee at 56 and apogee at 63.8.
     */
    static lunarDistance(date?: Date): number;
    /**
     * Name of the lunar phase per date submitted.
     */
    static lunarPhase(date?: Date, options?: Partial<MoonOptions>): LunarPhase;
    /**
     * Emoji of the lunar phase per date submitted.
     */
    static lunarPhaseEmoji(date?: Date, options?: Partial<MoonOptions>): SouthernHemisphereLunarEmoji | NorthernHemisphereLunarEmoji;
    /**
     * Emoji for specified lunar phase.
     */
    static emojiForLunarPhase(phase: LunarPhase, options?: Partial<MoonOptions>): SouthernHemisphereLunarEmoji | NorthernHemisphereLunarEmoji;
    /**
     * Whether the moon is currently waxing (growing).
     */
    static isWaxing(date?: Date): boolean;
    /**
     * Whether the moon is currently waning (shrinking).
     */
    static isWaning(date?: Date): boolean;
}

export declare type MoonOptions = {
    hemisphere?: Hemisphere | undefined;
};

/**
 * Enumeration of lunar phases as emoji for the Northern Hemisphere.
 */
export declare enum NorthernHemisphereLunarEmoji {
    NEW = "\uD83C\uDF11",
    WAXING_CRESCENT = "\uD83C\uDF12",
    FIRST_QUARTER = "\uD83C\uDF13",
    WAXING_GIBBOUS = "\uD83C\uDF14",
    FULL = "\uD83C\uDF15",
    WANING_GIBBOUS = "\uD83C\uDF16",
    LAST_QUARTER = "\uD83C\uDF17",
    WANING_CRESCENT = "\uD83C\uDF18"
}

/**
 * Enumeration of lunar phases as emoji for the Southern Hemisphere.
 */
export declare enum SouthernHemisphereLunarEmoji {
    NEW = "\uD83C\uDF11",
    WAXING_CRESCENT = "\uD83C\uDF18",
    FIRST_QUARTER = "\uD83C\uDF17",
    WAXING_GIBBOUS = "\uD83C\uDF16",
    FULL = "\uD83C\uDF15",
    WANING_GIBBOUS = "\uD83C\uDF14",
    LAST_QUARTER = "\uD83C\uDF13",
    WANING_CRESCENT = "\uD83C\uDF12"
}

/**
 * Units of measure
 */
export declare enum Unit {
    EARTH_RADII = "Earth Radii",
    KILOMETERS = "km",
    MILES = "m"
}

export { }
